import numpy as np
import matplotlib.pyplot as plt
from bodorientpy.errorprop import propagate_error


def plot_error_f(ax, func_f, x, delta_x, delta_y, x0):
    y0 = func_f(x0)
    xdelta = np.linspace(x0-delta_x, x0+delta_x, len(x))
    ydelta = np.linspace(y0-delta_y, y0+delta_y, len(x))
    y = func_f(x)
    ax.fill_between(xdelta, min(y), max(y), facecolor='k',
                    alpha=0.3, edgecolor='None')
    ax.fill_between(x, min(ydelta), max(ydelta),
                    facecolor='r', alpha=0.5, edgecolor='None')
    ax.plot(x, y, 'k', linewidth=2)

    ax.set_xlim([min(x), max(x)])
    ax.set_ylim([min(y), max(y)])
    ax.set_xlabel('x')
    ax.set_ylabel('y=f(x)')


def func_f(x):
    return (x+1)*(x-2)*(x+3)


delta_x = 0.5
x = np.linspace(-5, 4.5, 100)

fig, axarr = plt.subplots(1, 2, figsize=(15, 5))
x0 = -1
delta_y = propagate_error(func_f, x0, delta_x)
plot_error_f(axarr[0], func_f, x, delta_x, delta_y, x0=x0)
x0 = 3
delta_y = propagate_error(func_f, x0, delta_x)
plot_error_f(axarr[1], func_f, x, delta_x, delta_y, x0=x0)
fig.show()
